summaryrefslogtreecommitdiffstats
path: root/khtml/rendering/render_style.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'khtml/rendering/render_style.cpp')
-rw-r--r--khtml/rendering/render_style.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/khtml/rendering/render_style.cpp b/khtml/rendering/render_style.cpp
index 81d0b62ed..ecbbf6de2 100644
--- a/khtml/rendering/render_style.cpp
+++ b/khtml/rendering/render_style.cpp
@@ -726,7 +726,7 @@ bool RenderStyle::inheritedNotEqual( RenderStyle *other ) const
CbLayout: The containing block of the object needs a relayout.
Layout: the RenderObject needs a relayout after the style change
Visible: The change is visible, but no relayout is needed
- NonVisible: The object does need neither tqrepaint nor relayout after
+ NonVisible: The object does need neither repaint nor relayout after
the change.
### TODO:
@@ -744,7 +744,7 @@ RenderStyle::Diff RenderStyle::diff( const RenderStyle *other ) const
// EUserInput _user_input : 2; as long as :enabled is not impl'd
// ### this needs work to know more exactly if we need a relayout
// or just a tqrepaint
// non-inherited attributes
// DataRef<StyleBoxData> box;
@@ -744,7 +744,7 @@ RenderStyle::Diff RenderStyle::diff( const RenderStyle *other ) const
// EUserInput _user_input : 2; as long as :enabled is not impl'd
// ### this needs work to know more exactly if we need a relayout
-// or just a tqrepaint
+// or just a repaint
// non-inherited attributes
// DataRef<StyleBoxData> box;